NAME
Date::Parse - Parse date strings into time values
VERSION
version 2.35
SYNOPSIS
use Date::Parse;
my $date = "Wed, 16 Jun 94 07:29:35 CST";
my $time = str2time($date);
my ($ss,$mm,$hh,$day,$month,$year,$zone) = strptime($date);
DESCRIPTION
Date::Parse provides two routines for parsing date strings into time values.
- str2time(DATE [, ZONE [, EPOCH]])
-
str2timeparsesDATEand returns a unix time value, or undef upon failure.ZONE, if given, specifies the timezone to assume when parsing if the date string does not specify a timezone.EPOCH, if given, is a unix epoch value used as the reference time when filling in missing date components (month, day, or year). Defaults totime(). Useful when the current system clock cannot be trusted or when parsing dates relative to a known reference point. - strptime(DATE [, ZONE])
-
strptimetakes the same arguments as str2time but returns an array of values($ss,$mm,$hh,$day,$month,$year,$zone,$century). Elements are only defined if they could be extracted from the date string. An empty array is returned upon failure.The return values follow the same conventions as Perl's built-in
localtimeandgmtimefunctions:$month-
0-indexed: 0 = January, 1 = February, ..., 11 = December.
$year-
Years since 1900. For example, the year 2015 is returned as
115, and 1995 is returned as95. To recover the full 4-digit year:$year + 1900. $zone-
Timezone offset in seconds from UTC, or
undefif no timezone was specified in the input string. $century-
Defined only when a 4-digit year was present in the input. Its value is
int($full_year / 100)(e.g.20for the year 2015). When$centuryis defined,$year + 1900gives the original 4-digit year.
For example,
strptime("2015-01-24T09:08:17")returns:($ss, $mm, $hh, $day, $month, $year, $zone, $century) ( 17, 8, 9, 24, 0, 115, undef, 20 ) # ^--- January (0-indexed) # ^--- 2015 - 1900 # ^--- not in input # ^--- int(2015/100)
NAME
Date::Parse - Parse date strings into time values
MULTI-LANGUAGE SUPPORT
Date::Parse is capable of parsing dates in several languages, these include English, French, German and Italian.
$lang = Date::Language->new('German');
$lang->str2time("25 Jun 1996 21:09:55 +0100");
EXAMPLE DATES
Below is a sample list of dates that are known to be parsable with Date::Parse
1995-01-24T09:08:17.1823213 ISO-8601
Wed, 16 Jun 94 07:29:35 CST Comma and day name are optional
Thu, 13 Oct 94 10:13:13 -0700
Wed, 9 Nov 1994 09:50:32 -0500 (EST) Text in ()'s will be ignored.
21 dec 17:05 Will be parsed in the current time zone
21-dec 17:05
21/dec 17:05
21/dec/93 17:05
1999 10:02:18 "GMT"
16 Nov 94 22:28:20 PST
BUGS
When both the month and the date are specified in the date as numbers they are always parsed assuming that the month number comes before the date. This is the usual format used in American dates.
The reason why it is like this and not dynamic is that it must be deterministic. Several people have suggested using the current locale, but this will not work as the date being parsed may not be in the format of the current locale.
My plans to address this, which will be in a future release, is to allow the programmer to state what order they want these values parsed in.
AUTHOR
Graham Barr <gbarr@pobox.com>
COPYRIGHT
Copyright (c) 1995-2009 Graham Barr. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
AUTHOR
Graham <gbarr@pobox.com>
COPYRIGHT AND LICENSE
This software is copyright (c) 2020 by Graham Barr.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.